# PM Studio MCP

PM Studio MCP is a Model Context Protocol (MCP) server for product management tasks. It provides a suite of tools and utilities to help product managers analyze user feedback, perform competitive analysis, generate data visualizations, and access structured data sources.

## Getting Started
You may find keys in the loop file: https://microsoftapc.sharepoint.com/:fl:/r/contentstorage/x8FNO-xtskuCRX2_fMTHLbjHaHnyOSBPmaEXaBgV1fA/Document%20Library/Copilot/Key%20Vault.loop?d=waa77d19c735642939322fd824ee4c5b4&csf=1&web=1&e=rgZRBa& %3D

   ```
   {
      "mcpServers": {
         "pm-studio-mcp": {
               "command": "uvx",
               "args": [
                  "pm-studio-mcp"
               ],
               "env": {
                  "WORKING_PATH": "{PATH_TO_YOUR_WORKSPACE}/working_dir/",
                  "AZURE_KEY_VAULT_URL": "{AZURE_KEY_VAULT_URL}",
                  "AZURE_KEY_VAULT_TENANT_ID":"{AZURE_KEY_VAULT_TENANT_ID}",
                  "AZURE_KEY_VAULT_CLIENT_ID":"{AZURE_KEY_VAULT_CLIENT_ID}",
                  "AZURE_KEY_VAULT_CLIENT_SECRET":"{AZURE_KEY_VAULT_CLIENT_SECRET}",
               },
               "disabled": false
         }
      }
   }
   ```
